==> haskell-adjunctions-4.4.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 adjunctions
version:              4.4.3
visibility:           public
id:                   adjunctions-4.4.3-ENtJFH4rcGqJoKNuEi6nwR
key:                  adjunctions-4.4.3-ENtJFH4rcGqJoKNuEi6nwR
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  5c3a5d63a814a0873938e963b3bf5efe
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.3-ENtJFH4rcGqJoKNuEi6nwR
depends:
    array-0.5.4.0 base-4.17.2.1 comonad-5.0.9-9xjKvPyIFa3z6kb3iLImI
    containers-0.6.7 contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-EftPvaxxltk3GbMdYU389v
    free-5.2-O6Fl4ZQfrLF1HdcYmkQsm mtl-2.2.2
    profunctors-5.6.2-EsgLQtFnlIg5jr0U9yDwZT
    semigroupoids-6.0.1-4MzfMO8TUru5bIlkk6eiWh
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 adjunctions
version:              4.4.3
visibility:           public
id:                   adjunctions-4.4.3-GslgmzblhqqK8egLGUGYlj
key:                  adjunctions-4.4.3-GslgmzblhqqK8egLGUGYlj
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  dbe1ae37e9f723f8bc9796dbb5341134
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.3-GslgmzblhqqK8egLGUGYlj
depends:
    array-0.5.4.0 base-4.17.2.1 comonad-5.0.9-I51Kpbi3BnaLUdzI5pNpo6
    containers-0.6.7 contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-CYwgdClE26GLAL3gsDf3Vu
    free-5.2-HTynOWv6dRn8Hu1n2x55wZ mtl-2.2.2
    profunctors-5.6.3-IpMnxIdCmTIm3BKwO5i76
    semigroupoids-6.0.1-Jr4qwSJRHF330Efi7HW1er
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
